===================
cpskin.contenttypes
===================

CPskin related content types

.. image:: https://travis-ci.org/IMIO/cpskin.contenttypes.png
    :target: http://travis-ci.org/IMIO/cpskin.contenttypes

.. image:: https://coveralls.io/repos/github/IMIO/cpskin.contenttypes/badge.svg?branch=master
    :target: https://coveralls.io/github/IMIO/cpskin.contenttypes?branch=master


